@@ -1,5 +1,6 @@
 //! # Integers
 //!
 //! Fixed size and arbitrary precision, factorization into often-primes, nonzero signs.
-mod factorization;
+pub mod factorization;
 mod sign;
+pub mod big;
